( cd usr/lib64 ; rm -rf libXdamage.so.1 )
( cd usr/lib64 ; ln -sf libXdamage.so.1.1.0 libXdamage.so.1 )
( cd usr/lib64 ; rm -rf libXdamage.so )
( cd usr/lib64 ; ln -sf libXdamage.so.1.1.0 libXdamage.so )
